Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AliasDI ¶
type AliasDI struct {
Alias meta.Alias `json:"alias"`
Target string `json:"target"`
DryRun bool `json:"dry"`
}
AliasDI - Data Input(DI) format for requests that pass the alias data
type AliasQueryDI ¶
AliasQueryDI - Data Input format for queries requests
type AppQueryDI ¶
type AppQueryDI struct {
DryRun bool `json:"dry"`
}
AppQueryDI - Data Input format for queries requests
type AuthDI ¶
type AuthDI struct {
Token []byte `json:"token"`
}
AuthDI - Data Input format for authorization requests
type BrokerConfigDI ¶
type BrokerConfigDI struct {
BrokerName string `json:"brokername"`
FileContents []byte `json:"filecontents"`
}
BrokerConfigDI is the struct that defines the means in which the data used in operations related to creating or altering the broker in the insprd/cluster
type BrokersDI ¶
type BrokersDI struct {
Available utils.StringArray `json:"available"`
Default string `json:"default"`
}
BrokersDI data interface to provide broker information
type ChannelQueryDI ¶
ChannelQueryDI - Data Input format for queries requests
type TypeQueryDI ¶
TypeQueryDI - Data Input format for queries requests
Click to show internal directories.
Click to hide internal directories.